durationtools.rational_to_equal_or_greater_binary_rational
==========================================================

.. autofunction:: abjad.tools.durationtools.rational_to_equal_or_greater_binary_rational.rational_to_equal_or_greater_binary_rational
